@@ -1,8 +1,5 @@
 package Test::Mock::LWP::Dispatch;
-{
-  $Test::Mock::LWP::Dispatch::VERSION = '0.06';
-}
-
+$Test::Mock::LWP::Dispatch::VERSION = '0.07';
 use strict;
 use warnings;
 
@@ -25,6 +22,7 @@ use Test::MockObject;
 our $mock_ua;
 BEGIN {
     my $default_resp = HTTP::Response->new(404);
+    my $orig_simple_request_fn = \&LWP::UserAgent::simple_request;
 
 
 
@@ -94,6 +92,18 @@ BEGIN {
     }
 
 
+    sub map_passthrough {
+        my $mo = shift;
+
+        my ($req) = @_;
+        if (!defined($req)) {
+            croak "You should pass 1 argument to map_passthrough()";
+        }
+
+        return $mo->map($req, sub { return $orig_simple_request_fn->($mo, shift); });
+    }
+
+
     sub unmap {
         my $mo = shift;
         my $index = shift;
@@ -120,6 +130,7 @@ BEGIN {
     my %mock_methods = (
          simple_request => \&simple_request,
          map            => \&map,
+         map_passtrough => \&map_passthrough,
          unmap          => \&unmap,
          unmap_all      => \&unmap_all,
     );
@@ -136,13 +147,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Mock::LWP::Dispatch - mocks LWP::UserAgent and dispatches your requests/responses
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -163,18 +176,14 @@ version 0.06
 
 =head1 DESCRIPTION
 
-This module intends for testing a code that heavily uses LWP::UserAgent.
+This module is intended for testing a code that heavily uses LWP::UserAgent.
 
-Assume that function you want to test makes three different request to the server
-and expects to get some content from the server. To test this function you should
-setup request/response mappings for mocked UserAgent and test it.
+Assume that a function you want to test makes three different requests to a server and expects to get some content from the server. To test this function you should setup request/response mappings for mocked UserAgent and test it.
 
-For doing something with mappings, here are methods C<map>, C<unmap> and C<unmap_all>. For controlling context of these mappings (is it applies for all created in your
-code LWP::UserAgent's or only to one specific?) you should call these functions
+For doing something with mappings, here are methods C<map>, C<unmap> and C<unmap_all>. For controlling context of these mappings (whether it applies to all LWP::UserAgent-s created in your code or only to a specific one) you need to call these functions
 for exported C<$mock_ua> object (global mapping) or for newly created LWP::UserAgent (local mappings).
 
-See also on L<Test::Mock::LWP>, it provides mocked LWP objects for you, so probably
-you can solve your problems with this module too.
+See also L<Test::Mock::LWP>, it provides mocked LWP objects for you, so probably you can solve your problems with that module too.
 
 =head1 METHODS
 
@@ -182,25 +191,21 @@ you can solve your problems with this module too.
 
 =item simple_request($req)
 
-This is only method of LWP::UserAgent that mocked. When you make $ua->get(...)
-or $ua->head(...) or just get() from LWP::Simple, at some point calls
-C<simple_request()> method. So for controlling responses to your requests it is
-only method needed to mock.
+This is the only method of LWP::UserAgent that get mocked. When you call $ua->get(...) or $ua->head(...) or just get() from LWP::Simple, at some point it will call C<simple_request()> method. So there is no need to mock anything else as long as the desired goal is the ability to control responses to your requests.
 
-In this module C<simple_request()> loops through your local and global mappings
-(in this order) and returns response on a first matched mapping. If no matched
-C<simple_request()> returns HTTP::Response with 404 code.
+In this module C<simple_request()> loops through your local and global mappings (in this order) and returns response on a first matched mapping. If no matches found, then C<simple_request()> returns HTTP::Response with 404 code.
 
 Be accurate: method loops through mappings in order of adding these mappings.
 
 =item map($req_descr, $resp_descr)
 
-Using this method you can say what response should be on what request.
+Maps C<$req_descr> to the corresponding C<$resp_descr>.
 
-If you call this method for exported C<$mock_ua> it will make global mappings
-applied for all newly created LWP::UserAgent's. If you call this method for
-separate LWP::UserAgent you created, then this mapping will work only for
-this object.
+C<$req_descr> determines how to match an incoming request with a mapping.
+
+C<$resp_descr> determines what will be returned if the incoming request matches with C<$req_descr>.
+
+Calling this method for exported C<$mock_ua> will make global mappings applied to all newly created LWP::UserAgent-s. Calling this method for a separately created LWP::UserAgent will apply the mapping only to that object.
 
 Request description C<$req_descr> can be:
 
@@ -208,46 +213,47 @@ Request description C<$req_descr> can be:
 
 =item string
 
-Uri for exact matching with incoming request uri in C<request()>.
+Represents uri for exact match with the incoming request uri.
 
 =item regexp
 
-Regexp on what incoming request uri will match.
+Incoming request uri will be checked against this regexp.
 
 =item code
 
-You can pass arbitrary coderef, that takes incoming HTTP::Request and returns
-true if this request matched.
+An arbitrary coderef that takes incoming HTTP::Request and returns true if this request matched.
 
 =item HTTP::Request object
 
-If you pass such object, then request will compare that incoming request
-exactly the same that you passed in C<map()> (this means, that all query
-parameters, all headers and so on must be identical).
+Incoming request will match with this object if they are exactly the same: all the query parameters, headers and so on must be identical.
 
 =back
 
-Response description C<$resp_descr>, that will be returned if incoming request
-to C<request()> matches with C<$req_descr>, can be:
+Response description C<$resp_descr> can be:
 
 =over 4
 
 =item HTTP::Response object
 
-Ready to return HTTP::Response object.
+This object will be returned.
 
 =item code
 
-Arbitrary coderef, that takes incoming request as parameter and returns
-HTTP::Response object.
+An arbitrary coderef that takes incoming request as parameter and returns HTTP::Response object.
 
 =back
 
 Method returns index of your mapping. You can use it in C<unmap>.
 
+=item map_passthrough($req_descr)
+
+Will pass through the $req_descr to actual LWP::UserAgent. See L<map> for $req_descr.
+
+Example to let LWP::UserAgent handle all file:// urls: C<$mock_ua-E<gt>map_passtrough(qr{^file://});>
+
 =item unmap($map_index)
 
-Deletes some mapping by index.
+Deletes a mapping by index.
 
 =item unmap_all
 
@@ -259,23 +265,19 @@ Deletes all mappings.
 
 =head2 DEFAULT_REQUEST_HEADERS
 
-LWP::UserAgent sets default headers for requests by calling
-LWP::UserAgent->prepare_request().
+LWP::UserAgent sets default headers for requests by calling LWP::UserAgent->prepare_request().
 
-Previous versions (<= 0.05) of Test:Mock::LWP::Dispatch didn't intercept this call
-in overridden C<simple_request()>.
+Previous versions (<= 0.05) of Test:Mock::LWP::Dispatch didn't intercept this call in overridden C<simple_request()>.
 
 Now Test::Mock::LWP::Dispatch does it by default.
 
-If for some reason you want to get back previous behaviour of the module,
-set the following variable off:
+If for some reason you want to get back the previous behaviour of the module, set the following variable off:
 
 $Test::Mock::LWP::Dispatch::DEFAULT_REQUEST_HEADERS = 0;
 
 =head1 MISCELLANEOUS
 
-This mock object doesn't call C<fake_new()>. So when you prepare response using
-coderef, you can be sure, that "User-Agent" header will be untouched and so on.
+This mock object doesn't call C<fake_new()>. So when you prepare response using coderef, you can be sure that "User-Agent" header will be untouched and so on.
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -287,6 +289,8 @@ Ash Berlin
 
 Joe Papperello
 
+Slobodan Mišković
+
 =head1 SEE ALSO
 
 L<http://github.com/tadam/Test-Mock-LWP-Dispatch>
@@ -301,7 +305,7 @@ Yury Zavarin <yury.zavarin@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yury Zavarin.
+This software is copyright (c) 2015 by Yury Zavarin.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
